@@ -211,28 +211,14 @@ def open_nwp(zarr_path: str, consolidated: bool) -> xr.DataArray:
         ukv = ukv.reindex(y=y_reversed)
 
     # Sanity checks.
-    # If there are any duplicated init_times then drop the duplicated init_times:
-    init_time = pd.DatetimeIndex(ukv["init_time"])
-    if not init_time.is_unique:
-        n_duplicates = init_time.duplicated().sum()
-        _LOG.warning(f"NWP Zarr has {n_duplicates:,d} duplicated init_times.  Fixing...")
-        ukv = ukv.drop_duplicates(dim="init_time")
-        init_time = pd.DatetimeIndex(ukv["init_time"])
+    ukv = utils.drop_duplicate_times(data_array=ukv, class_name="NWP", time_dim="init_time")
 
     # If any init_times are not monotonic_increasing then drop the out-of-order init_times:
-    if not init_time.is_monotonic_increasing:
-        total_n_out_of_order_times = 0
-        _LOG.warning("NWP Zarr init_time is not monotonic_increasing.  Fixing...")
-        while not init_time.is_monotonic_increasing:
-            diff = np.diff(init_time.view(int))
-            out_of_order = np.where(diff < 0)[0]
-            total_n_out_of_order_times += len(out_of_order)
-            out_of_order = init_time[out_of_order]
-            ukv = ukv.drop_sel(init_time=out_of_order)
-            init_time = pd.DatetimeIndex(ukv["init_time"])
-        _LOG.info(f"Fixed {total_n_out_of_order_times:,d} out of order init_times.")
+    ukv = utils.drop_non_monotonic_increasing(
+        data_array=ukv, class_name="NWP", time_dim="init_time"
+    )
 
-    assert init_time.is_unique
-    assert init_time.is_monotonic_increasing
+    assert pd.DatetimeIndex(ukv["init_time"]).is_unique
+    assert pd.DatetimeIndex(ukv["init_time"]).is_monotonic_increasing
 
     return ukv
