@@ -1,8 +1,6 @@
 """ Model for output of Optical Flow data """
 from __future__ import annotations
 
-import numpy as np
-
 from nowcasting_dataset.data_sources.datasource_output import DataSourceOutput
 
 
@@ -16,7 +14,10 @@ class OpticalFlow(DataSourceOutput):
     @classmethod
     def model_validation(cls, v):
         """Check that all values are not NaN, Infinite, or -1."""
-        assert (~np.isnan(v.data)).all(), "Some optical flow data values are NaNs"
-        assert (~np.isinf(v.data)).all(), "Some optical flow data values are Infinite"
-        assert (v.data != -1).all(), "Some optical flow data values are -1"
+        v.check_nan_and_inf(data=v.data)
+        # previously nans were filled with -1s, so lets make sure there are none
+        v.check_dataset_not_equal(data=v.data, value=-1)
+        v.check_data_var_dim(v.x_osgb, ("example", "x_osgb_index"))
+        v.check_data_var_dim(v.y_osgb, ("example", "y_osgb_index"))
+
         return v
